require 'spec_helper'

module Falcore
  describe Aggregator do
    let(:endpoint) { 'http://jenkins.local' }
    let(:config)   { Config.new(endpoint: endpoint) }
    let(:computer) { JSON.parse(File.read(File.expand_path('../../fixtures/computer.json', __FILE__))) }

    before do
      Fetcher.stub(:get).and_return(computer)
    end

    subject { Aggregator.new(config) }

    describe '#run' do
      let(:master) { subject.run }

      it 'returns a master jenkins node' do
        expect(master).to be_a(Node::Master)
      end

      it 'adds the slaves to the master' do
        expect(master.slaves.size).to eq(3)
      end

      it 'correctly builds each slave object' do
        expect(master.slaves[0].display_name).to eq('slave1.jenkins.example.com')
        expect(master.slaves[1].display_name).to eq('slave2.jenkins.example.com')
        expect(master.slaves[2].display_name).to eq('slave3.jenkins.example.com')
      end
    end
  end
end
