require 'spec_helper'

module Falcore
  describe Config do
    describe '.from_file' do
      context 'when the file does not exist' do
        before { File.stub(:read).and_raise(Errno::ENOENT) }

        it 'raises an exception' do
          expect { Config.from_file('/foo/bar') }.to raise_error(RuntimeError)
        end
      end

      context 'when the file exists' do
        let(:path)   { '/config/file' }
        let(:config) { Config.from_file(path) }
        let(:contents) do
          <<-EOH.gsub(/^ {12}/, '')
            [jenkins]
              endpoint = http://localhost

            [statsd]
              host = http://my.statsd.server
              port = 8125

            # This section is commented out for testing purposes
            # [nrpe]
            #   out = STDOUT
          EOH
        end

        before { File.stub(:read).with(path).and_return(contents) }

        it 'returns a config object' do
          expect(config).to be_a(Config)
        end

        it 'has the properly nested keys' do
          expect(config.jenkins.endpoint).to eq('http://localhost')
          expect(config.statsd.host).to eq('http://my.statsd.server')
          expect(config.statsd.port).to eq(8125)
        end

        it 'returns a NullObject for ultimate awesomeness' do
          expect(config.foo).to be_nil
          expect(config.foo.bar.zip.zap.billy.bob).to be_nil
        end

        it 'ignores commented lines' do
          expect(config).to_not have_key('nrpe')
        end
      end
    end
  end
end
